@@ -1,8 +1,10 @@
 """No authentication strategy implementation"""
+
 from typing import Dict, Any
 from .auth import AuthBase
 from playwright.async_api import BrowserContext
 
+
 class NoAuth(AuthBase):
     """Authentication strategy that doesn't persist any data"""
 
@@ -11,9 +13,7 @@ class NoAuth(AuthBase):
 
     def get_browser_args(self) -> Dict[str, Any]:
         """Get browser launch arguments"""
-        return {
-            "headless": False
-        }
+        return {"headless": False}
 
     async def setup_context(self, context: BrowserContext) -> None:
         """No special configuration needed"""
